# PySFCGAL

An official wrapper around the SFCGAL library for Python in the style of Shapely.

http://www.sfcgal.org/

This modules is in the *very* early stages of development!

## Installation

See [build page](build.md)

## Credits
 
Initial work from https://github.com/snorfalorpagus/pysfcgal/
